orderbook_drop

Function orderbook_drop 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn orderbook_drop(book: *mut OrderBook)
Safety

book must be a live owning pointer returned by orderbook_new, and must not be used after this call.

Panics

Panics if book is null.